pub enum ApiAction {
Show 32 variants
PutBootSource(BootSourceConfig),
PutDrive(DriveConfig),
PatchDrive(DrivePatch),
DeleteDrive {
drive_id: DriveId,
},
PutNetwork(NetworkInterfaceConfig),
PatchNetwork(NetworkPatch),
DeleteNetwork {
iface_id: IfaceId,
},
PutVsock(VsockConfig),
PutMmds(MmdsContents),
PatchMmds(MmdsContents),
PutMmdsConfig(MmdsConfig),
PutBalloon(BalloonConfig),
PatchBalloon(BalloonUpdate),
PatchBalloonStats(BalloonStatsUpdate),
PatchBalloonHinting {
op: BalloonHintingOp,
},
PutEntropy(EntropyConfig),
PutSerial(SerialConfig),
PutPmem(PmemConfig),
PatchPmem(PmemPatch),
DeletePmem {
pmem_id: DriveId,
},
PutHotplugMemory(HotplugMemoryConfig),
PatchHotplugMemory(HotplugMemoryUpdate),
PutCpuConfig(CpuConfig),
PutMachineConfig(MachineConfig),
PatchMachineConfig(MachineConfigPatch),
PutLogger(LoggerConfig),
PutMetrics(MetricsConfig),
Action(InstanceAction),
PatchVm(VmStateChange),
SnapshotCreate(SnapshotCreateConfig),
SnapshotLoad(SnapshotLoadConfig),
Shutdown,
}Expand description
Mutating action posted onto the API → VMM channel.
Variants
PutBootSource(BootSourceConfig)
PUT /boot-source.
PutDrive(DriveConfig)
PUT /drives/{id}.
PatchDrive(DrivePatch)
PATCH /drives/{id}.
DeleteDrive
DELETE /drives/{id}.
PutNetwork(NetworkInterfaceConfig)
PUT /network-interfaces/{id}.
PatchNetwork(NetworkPatch)
PATCH /network-interfaces/{id}.
DeleteNetwork
DELETE /network-interfaces/{id}.
PutVsock(VsockConfig)
PUT /vsock.
PutMmds(MmdsContents)
PUT /mmds — replace MMDS data store.
PatchMmds(MmdsContents)
PATCH /mmds — JSON-merge-patch on the data store.
PutMmdsConfig(MmdsConfig)
PUT /mmds/config.
PutBalloon(BalloonConfig)
PUT /balloon.
PatchBalloon(BalloonUpdate)
PATCH /balloon.
PatchBalloonStats(BalloonStatsUpdate)
PATCH /balloon/statistics.
PatchBalloonHinting
PATCH /balloon/hinting/{op}.
Fields
op: BalloonHintingOpstart | status | stop.
PutEntropy(EntropyConfig)
PUT /entropy.
PutSerial(SerialConfig)
PUT /serial.
PutPmem(PmemConfig)
PUT /pmem/{id}.
PatchPmem(PmemPatch)
PATCH /pmem/{id}.
DeletePmem
DELETE /pmem/{id}.
PutHotplugMemory(HotplugMemoryConfig)
PUT /hotplug/memory.
PatchHotplugMemory(HotplugMemoryUpdate)
PATCH /hotplug/memory.
PutCpuConfig(CpuConfig)
PUT /cpu-config.
PutMachineConfig(MachineConfig)
PUT /machine-config.
PatchMachineConfig(MachineConfigPatch)
PATCH /machine-config.
PutLogger(LoggerConfig)
PUT /logger.
PutMetrics(MetricsConfig)
PUT /metrics.
Action(InstanceAction)
PUT /actions — every action variant including InstanceStart.
PatchVm(VmStateChange)
PATCH /vm — pause/resume.
SnapshotCreate(SnapshotCreateConfig)
PUT /snapshot/create.
SnapshotLoad(SnapshotLoadConfig)
PUT /snapshot/load.
Shutdown
SIGINT / process shutdown.
Implementations
Sourceimpl ApiAction
impl ApiAction
Sourcepub const fn class(&self) -> ActionClass
pub const fn class(&self) -> ActionClass
The timeout class for this action.
Sourcepub const fn is_pre_boot(&self) -> bool
pub const fn is_pre_boot(&self) -> bool
true if this action should be admissible before the microVM has booted.
Sourcepub const fn is_post_boot(&self) -> bool
pub const fn is_post_boot(&self) -> bool
true if this action is admissible after the microVM has booted.