pub async fn serve(
opts: ServeOptions,
controller: Arc<RuntimeApiController>,
) -> Result<()>Expand description
Bind a Unix domain socket and serve the API on it until the future is dropped.
Errors
Returns an error if the socket file cannot be unlinked, the bind fails, or the underlying axum service errors.